======================
Octavia Administration
======================


Getting Started
---------------

.. toctree::
   :maxdepth: 1

   ../reference/introduction.rst
   ../reference/glossary.rst

APIs
----

.. toctree::
   :maxdepth: 1

   Octavia API Reference <https://developer.openstack.org/api-ref/load-balancer/>
   ../contributor/api/haproxy-amphora-api.rst


Operator Reference
------------------

.. toctree::
   :maxdepth: 1

   ../contributor/guides/dev-quick-start.rst
   guides/operator-maintenance.rst
   ../configuration/configref.rst
   ../configuration/policy.rst
   Anchor.rst
   apache-httpd.rst

Indices and Search
------------------

* :ref:`search`
